This project follows the CurioSwitch code of conduct.

> [!WARNING]
> Any following content is overridden by the laws of CurioSwitch's residing country, Japan.
> For example, things like death threats will be dealt with strictly.

There is just one guideline: be fair. It is not possible to define fairness precisely
but consider these examples when thinking about it.

Fair:

- Respond promptly to submitted issues / PRs.
  - Contributors spend time on submissions and it is not fair to not do the same in return.
- Aim for robust / tested code and systems.
  - It is not fair to users to give them a tool that only half-works and causes them frustration.
- Acknowledge others' points, even if disagreeing, instead of ignoring.
  - People engage in good faith, and it is not fair to leave it wasted.

Unfair:

- Keep issues about bugs or significant pain points open for a long time or suggest the contributor can raise a PR.
  - Users are not maintainers and it is not fair to expect them to become one to fix a bug
    (it is always welcome when they have the time and will to contribute though).
- Prioritize issues and discussions with friends, acquaintances, or those in the same timezone over others.
  - This is OSS and it is not fair to create boundaries or factions within it.

We are not perfect and may act in a way that isn't fair. This is fine and generally will not
need punitive measures - we will aim to improve over time. But do accept feedback about it in
good faith and respond to it fairly. If you need to provide feedback related to the above in
a private matter, feel free to email oss@curioswitch.org and we will aim to help in a fair
manner.
